C#
====

This file contains prerequisites and examples for working with **AuthHeadersBuilder** library using `HttpClient` lib.

HttpClient
----

### Prerequisites:

Request examples below are based on the internal `HttpClient` library. It can be used without adding any additional
dependencies.

Import the needed modules:

    using System.Text;
    using System.Net.Http.Headers;

### Examples:

- GET request:

        public static void GetRequest()
        {
            string apiKey = "API_KEY";
            string apiSecret = "API_SECRET";

            Uri uri = new Uri("https://www.example.com/resources");

            HttpMethod httpMethod = HttpMethod.Get;

            HttpClient client = new HttpClient();

            HttpRequestMessage httpRequest = new HttpRequestMessage(httpMethod, uri);
            Dictionary<string, string> headers = AuthHeadersBuilder.GenerateAuthHeaders(
                apiKey,
                apiSecret,
                httpMethod.Method.ToLower(),
                uri);
            foreach (KeyValuePair<string, string> header in headers)
            {
                httpRequest.Headers.Add(header.Key, header.Value);
            }

            var response = client.SendAsync(httpRequest).Result;
        }

- POST request:

        public static void PostRequest()
        {
            string apiKey = "API_KEY";
            string apiSecret = "API_SECRET";

            Uri uri = new Uri("https://www.example.com/resources");

            string data = "REQUEST_BODY";

            HttpMethod httpMethod = HttpMethod.Post;
            Encoding encoding = Encoding.UTF8;
            string contentType = "application/json";

            HttpClient client = new HttpClient();

            HttpRequestMessage httpRequest = new HttpRequestMessage(httpMethod, uri);
            Dictionary<string, string> headers = AuthHeadersBuilder.GenerateAuthHeaders(
                apiKey,
                apiSecret,
                httpMethod.Method.ToLower(),
                uri,
                contentType,
                data);
            foreach (KeyValuePair<string, string> header in headers)
            {
                httpRequest.Headers.Add(header.Key, header.Value);
            }
            httpRequest.Content = new StringContent(data, encoding, contentType);
            httpRequest.Content.Headers.ContentType = MediaTypeHeaderValue.Parse(contentType);

            var response = client.SendAsync(httpRequest).Result;
        }

- PUT request

        public static void PutRequest()
        {
            string apiKey = "API_KEY";
            string apiSecret = "API_SECRET";

            Uri uri = new Uri("https://www.example.com/resources");

            string data = "REQUEST_BODY";

            HttpMethod httpMethod = HttpMethod.Put;
            Encoding encoding = Encoding.UTF8;
            string contentType = "application/json";                

            HttpClient client = new HttpClient();

            HttpRequestMessage httpRequest = new HttpRequestMessage(httpMethod, uri);
            Dictionary<string, string> headers = AuthHeadersBuilder.GenerateAuthHeaders(
                apiKey,
                apiSecret,
                httpMethod.Method.ToLower(),
                uri,
                contentType,
                data);
            foreach (KeyValuePair<string, string> header in headers)
            {
                httpRequest.Headers.Add(header.Key, header.Value);
            }
            httpRequest.Content = new StringContent(data, encoding, contentType);
            httpRequest.Content.Headers.ContentType = MediaTypeHeaderValue.Parse(contentType);

            var response = client.SendAsync(httpRequest).Result;
        }

- DELETE request

        public static void DeleteRequest()
        {
            string apiKey = "API_KEY";
            string apiSecret = "API_SECRET";

            Uri uri = new Uri("https://www.example.com/resources");

            HttpMethod httpMethod = HttpMethod.Delete;

            HttpClient client = new HttpClient();

            HttpRequestMessage httpRequest = new HttpRequestMessage(httpMethod, uri);
            Dictionary<string, string> headers = AuthHeadersBuilder.GenerateAuthHeaders(
                apiKey,
                apiSecret,
                httpMethod.Method.ToLower(),
                uri);
            foreach (KeyValuePair<string, string> header in headers)
            {
                httpRequest.Headers.Add(header.Key, header.Value);
            }

            var response = client.SendAsync(httpRequest).Result;
        }
